@@ -1,6 +1,7 @@
 """Main module."""
 
 import re
+import asyncio
 from asyncio import get_event_loop, wait_for
 from codecs import lookup
 from functools import partial
@@ -10,6 +11,7 @@ from io import IOBase
 from json import dumps, loads
 from os.path import basename
 from random import randint
+import sys
 from ssl import SSLContext
 from typing import (
     Any,
@@ -241,19 +243,33 @@ class HttpResponse:
 
     async def read_chunks(self) -> AsyncIterator[bytes]:
         """Read chunks from chunked response."""
+        if not self.connection:
+            raise ConnectionError('not connection present')
+
         while True and not self.chunks_readed:
-            chunk_size = int((await
-                              self.connection.reader.readline()).rstrip(), 16)
+            chunk_size = int((await self.connection.reader.readline())
+                             .rstrip(), 16)
             if not chunk_size:
                 # read last CRLF
                 await self.connection.reader.readline()
                 # free connection
                 await self.connection.release()
                 break
-            chunk = await self.connection.reader.readexactly(chunk_size + 2)
+            chunk = await self.connection.reader.readexactly(
+                    chunk_size + 2)
             yield chunk[:-2]
         self.chunks_readed = True
 
+    def __del__(self):
+        # clean it
+        if self.chunked and not self.chunks_readed:
+            loop = None
+            if sys.version_info >= (3, 7):
+                loop = asyncio.get_running_loop()
+            else:
+                loop = asyncio.get_event_loop()
+            loop.create_task(self.connection.release())
+
 
 def _get_header_data(url: ParseResult,
                      connection: Connection,
@@ -416,6 +432,7 @@ async def _do_request(urlparsed: ParseResult,
                       http2: bool = False) -> HttpResponse:
     """Something."""
     async with (await connector.acquire(urlparsed)) as connection:
+        timeouts = timeouts or connector.timeouts
         await connection.connect(urlparsed, verify, ssl, timeouts, http2)
         to_send = headers_data(connection=connection)
 
@@ -437,16 +454,15 @@ async def _do_request(urlparsed: ParseResult,
 
         # get response code and version
         try:
-            response._set_response_initial(await wait_for(
-                connection.reader.readline(),
-                (timeouts or connector.timeouts).sock_read))
+            response._set_response_initial(
+                await wait_for(
+                    connection.reader.readline(), timeouts.sock_read))
         except TimeoutException:
             raise ReadTimeout()
 
-        res_data = None
         # reading headers
-
-        await response._set_response_headers(_parse_headers_iterator(connection))
+        await response._set_response_headers(
+            _parse_headers_iterator(connection))
 
         size = response.headers.get('content-length')
         chunked = response.headers.get('transfer-encoding', '') == 'chunked'
@@ -460,7 +476,7 @@ async def _do_request(urlparsed: ParseResult,
             connection.block_until_read_chunks()
             response.chunked = True
 
-        if keepalive:
+        if keepalive or chunked:
             connection.keep_alive()
             response._set_connection(connection)
         return response
